# LTEpy

LTEpy is a python package for calculating and visualizing functions in local thermodynamic equilibrium, including:
* The Planck Function for black body radiation
* The Maxwell Boltzmann Distribution
* The Boltzmann Factors for an atom's energy levels

# Installation

Install LTEpy and its requirements with pip using

`pip install -e LTEpy -r LTEpy/requirements.txt`


# Documentation

See documentation and tutorials on [readthedocs](https://ltepy.readthedocs.io/en/latest/).

# Attribution

For attribution, cite the [LTEpy zenodo](https://zenodo.org/record/8139888).

LTEpy uses an [MIT license](LICENSE).

# Acknowledgements
This package was developed at the [code/astro](https://semaphorep.github.io/codeastro/) workshop. Special thanks to the code/astro instructors, Sarah Blunt, Matthew Hosek, and Jason Wang, and the teaching assistant overseeing this project, Simon Ko.


[![Code/Astro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)
[![Documentation Status](https://readthedocs.org/projects/ltepy/badge/?version=latest)](https://ltepy.readthedocs.io/en/latest/?badge=latest)
[![DOI](https://zenodo.org/badge/664794683.svg)](https://zenodo.org/badge/latestdoi/664794683)

